@@ -1767,3 +1767,25 @@ def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False,
                       map(getCmd,
                           filter(lambda x: x.isdigit(),
                                  listDirectory('/proc'))))
+
+class XAttrError(Exception):
+    pass
+
+class xattr(object):
+    getfattr = '/bin/getfattr'
+    setfattr = '/bin/setfattr'
+
+    @classmethod
+    def get(cls, dn, attrname):
+        p = process(cls.getfattr, "-n", attrname, "--only-values", dn)
+        if p.success():
+            return p.read()
+        err = p.readerr()
+        raise XAttrError(err.partition(":")[2].strip())
+
+    @classmethod
+    def set(cls, dn, attrname, value):
+        p = process(cls.setfattr, "-n", attrname, "-v", value, dn)
+        if not p.success():
+            err = p.readerr()
+            raise XAttrError(err.rpartition(":")[2].strip())
