@@ -57,3 +57,6 @@ class VariableAcCustomName(Variable):
     def check(self, value):
         if value == '':
             raise VariableError(_("Need to specify an action name"))
+
+    def raiseNothingValue(self):
+        raise VariableError(_("No custom action on this system"))
