@@ -107,7 +107,7 @@ class Locale(object):
             'timezone': 'Europe/Athens',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
-            'xkblayout': 'gr',
+            'xkblayout': 'us,gr',
             'language': 'gr',
         }),
         ('en_AU', {
